/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.activeinstalls2.internal.data;

import java.util.function.Function;

import javax.inject.Inject;

import org.apache.commons.lang3.exception.ExceptionUtils;
import org.slf4j.Logger;
import org.xwiki.activeinstalls2.internal.PingDataProvider;

import co.elastic.clients.elasticsearch.ElasticsearchClient;
import co.elastic.clients.elasticsearch.indices.IndexSettings;
import co.elastic.clients.util.ObjectBuilder;

/**
 * To be extended by {@link PingDataProvider} implementations to simplify the code.
 *
 * @version $Id: bc3b4f36886143b8d396d3f1cd9d58b644b3d3ba $
 * @since 14.4RC1
 */
public abstract class AbstractPingDataProvider implements PingDataProvider
{
    @Inject
    private Logger logger;

    @Override
    public void setup(ElasticsearchClient client) throws Exception
    {
        // Overwrite to do something.
    }

    @Override
    public Function<IndexSettings.Builder, ObjectBuilder<IndexSettings>> provideIndexSettings()
    {
        // Overwrite to do something.
        return b0 -> b0;
    }

    protected void logWarning(String explanation, Throwable e)
    {
        this.logger.warn("{}. This information has not been added to the Active Installs ping data. Reason [{}]",
            explanation, ExceptionUtils.getRootCauseMessage(e));
    }
}
