/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.edit.script;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.edit.Editor;
import org.xwiki.rendering.block.XDOM;

/**
 * Edit script service specialized in {@link XDOM} {@link Editor}s.
 * 
 * @version $Id: 3f066fef827b776882d96ff32e78b3d46ebff92d $
 * @since 8.2RC1
 */
@Component
@Singleton
@Named(EditScriptService.ROLE_HINT + ".xdom")
public class XDOMEditScriptService extends AbstractTypedEditScriptService<XDOM>
{
    /**
     * @return the default {@link XDOM} editor in the "Text" category
     */
    public Editor<XDOM> getDefaultTextEditor()
    {
        return getDefaultEditor("text");
    }

    /**
     * @return the default {@link XDOM} editor in the "WYSIWYG" category
     */
    public Editor<XDOM> getDefaultWysiwygEditor()
    {
        return getDefaultEditor("wysiwyg");
    }
}
