/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.security.internal.livedata;

import javax.inject.Inject;
import javax.inject.Named;
import javax.inject.Provider;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.livedata.LiveDataConfiguration;
import org.xwiki.livedata.LiveDataConfigurationResolver;
import org.xwiki.livedata.internal.JSONMerge;

/**
 * Adds missing live data configuration values specific to the extension security source.
 *
 * @version $Id: 6ef473932576425745d7adddc7e9b0e14edeeb8f $
 * @since 15.5RC1
 */
@Component
@Singleton
@Named(ExtensionSecurityLiveDataSource.ID)
public class ExtensionSecurityLiveDataConfigurationResolver
    implements LiveDataConfigurationResolver<LiveDataConfiguration>
{
    @Inject
    @Named(ExtensionSecurityLiveDataSource.ID)
    private Provider<LiveDataConfiguration> extensionSecurityLiveDataProvider;

    @Override
    public LiveDataConfiguration resolve(LiveDataConfiguration input)
    {
        return new JSONMerge().merge(input, this.extensionSecurityLiveDataProvider.get());
    }
}
