/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.livedata;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.xwiki.text.XWikiToStringBuilder;

/**
 * Base class for various live data configuration descriptors.
 * 
 * @version $Id: 4f9bac9fbcc6a2eb706d3decdd2b3cff162e0bdb $
 * @since 12.10
 */
public class BaseDescriptor extends WithParameters
{
    private String id;

    /**
     * @return the id
     */
    public String getId()
    {
        return id;
    }

    /**
     * Set the id.
     * 
     * @param id the new id
     */
    public void setId(String id)
    {
        this.id = id;
    }

    @Override
    public int hashCode()
    {
        return new HashCodeBuilder().appendSuper(super.hashCode()).append(getId()).build();
    }

    @Override
    public boolean equals(Object obj)
    {
        if (obj == this) {
            return true;
        }

        if (obj instanceof BaseDescriptor) {
            BaseDescriptor other = (BaseDescriptor) obj;
            return new EqualsBuilder().appendSuper(super.equals(other)).append(getId(), other.getId()).build();
        }

        return false;
    }

    @Override
    public String toString()
    {
        return new XWikiToStringBuilder(this)
            .appendSuper(super.toString())
            .append("id", id)
            .toString();
    }
}
