/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.livedata.rest;

import javax.ws.rs.DefaultValue;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.core.Response;

import org.xwiki.livedata.LiveDataSource;
import org.xwiki.livedata.rest.model.jaxb.Properties;
import org.xwiki.livedata.rest.model.jaxb.PropertyDescriptor;

/**
 * Provides the list of known properties from an existing {@link LiveDataSource}.
 * 
 * @version $Id: c4c56c5afed6afaa426bc6ff8ecd22a21218e1af $
 * @since 12.10
 */
@Path("/liveData/sources/{sourceId}/properties")
public interface LiveDataPropertiesResource
{
    /**
     * Provides the list of properties known by a specific {@link LiveDataSource} implementation.
     * 
     * @param sourceId indicates the {@link LiveDataSource} component implementation
     * @param namespace the component manager name-space where to look for {@link LiveDataSource} implementations; if
     *            not specified then the context / current name-space is used
     * @return the list of properties known / supported by specified {@link LiveDataSource} component implementation
     * @throws Exception if retrieving the list of properties fails
     */
    @GET
    Properties getProperties(
        @PathParam("sourceId") String sourceId,
        @QueryParam("namespace") @DefaultValue("") String namespace
    ) throws Exception;

    /**
     * Adds a new property to the data set.
     * 
     * @param sourceId indicates the {@link LiveDataSource} component implementation
     * @param namespace the component manager name-space where to look for {@link LiveDataSource} implementations; if
     *            not specified then the context / current name-space is used
     * @param propertyDescriptor describes the property to add
     * @return the response
     * @throws Exception if adding the property fails
     */
    @POST
    Response addProperty(
        @PathParam("sourceId") String sourceId,
        @QueryParam("namespace") @DefaultValue("") String namespace,
        PropertyDescriptor propertyDescriptor
    ) throws Exception;
}
