/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.mentions.internal;

import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.xwiki.text.XWikiToStringBuilder;

/**
 * Represent the unique reference of a mentioned actor, composed of its serialized reference and its type.
 *
 * @version $Id: b8f73cea9117fc61c211b72c9088d534fdba0ab1 $
 * @since 12.10
 */
public class MentionedActorReference
{
    private final String reference;

    private final String type;

    /**
     * Default constructor.
     *
     * @param reference the mentioned user reference
     * @param type the type of the mentioned user
     */
    public MentionedActorReference(String reference, String type)
    {
        this.reference = reference;
        this.type = type;
    }

    /**
     *
     * @return the mentioned user reference
     */
    public String getReference()
    {
        return this.reference;
    }

    /**
     *
     * @return the mentioned user type
     */
    public String getType()
    {
        return this.type;
    }

    @Override
    public boolean equals(Object o)
    {
        if (this == o) {
            return true;
        }

        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        MentionedActorReference that = (MentionedActorReference) o;

        return new EqualsBuilder()
            .append(this.reference, that.reference)
            .append(this.type, that.type)
            .isEquals();
    }

    @Override
    public int hashCode()
    {
        return new HashCodeBuilder(17, 37)
            .append(this.reference)
            .append(this.type)
            .toHashCode();
    }

    @Override
    public String toString()
    {
        return new XWikiToStringBuilder(this)
            .append("reference", this.getReference())
            .append("type", this.getType())
            .build();
    }
}
