/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.model.reference;

import org.junit.jupiter.api.Test;
import org.xwiki.model.EntityType;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertSame;
import static org.junit.jupiter.api.Assertions.assertThrows;

/**
 * Unit tests for {@link AttachmentReference}.
 *
 * @version $Id: 1fa99213f73bbb9a72719c7159c9f39e35e9baf7 $
 * @since 2.2M1
 */
public class AttachmentReferenceTest
{
    @Test
    public void testInvalidType()
    {
        IllegalArgumentException e = assertThrows(IllegalArgumentException.class,
            () -> new AttachmentReference(new EntityReference("filename", EntityType.DOCUMENT)));

        assertEquals("Invalid type [DOCUMENT] for an attachment reference", e.getMessage());
    }

    @Test
    public void testInvalidNullParent()
    {
        IllegalArgumentException e =
            assertThrows(IllegalArgumentException.class, () -> new AttachmentReference("filename", null));

        assertEquals("Invalid parent reference [null] in an attachment reference", e.getMessage());
    }

    @Test
    public void testInvalidParentType()
    {
        IllegalArgumentException e = assertThrows(IllegalArgumentException.class, () -> new AttachmentReference(
            new EntityReference("filename", EntityType.ATTACHMENT, new WikiReference("wiki"))));

        assertEquals("Invalid parent reference [Wiki wiki] in an attachment reference", e.getMessage());
    }

    @Test
    public void testReplaceParent()
    {
        AttachmentReference reference = new AttachmentReference("file", new DocumentReference("wiki", "space", "page"))
            .replaceParent(new DocumentReference("wiki2", "space2", "page2"));

        assertEquals(new AttachmentReference("file", new DocumentReference("wiki2", "space2", "page2")), reference);

        assertSame(reference, reference.replaceParent(reference.getParent()));
    }
}
