/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.notifications.filters.expression.generics;

import org.xwiki.notifications.filters.expression.AndNode;
import org.xwiki.notifications.filters.expression.OrNode;

/**
 * Generic operator node definition for filtering expressions.
 *
 * @version $Id: 1ba862b0ef5b07625ee1705efd8c2b53703a6430 $
 * @since 9.8RC1
 */
public abstract class AbstractOperatorNode extends AbstractNode
{
    /**
     * Helper to construct new {@link AndNode} using the current object.
     *
     * @param node the node that should be the second operand of the AND node
     * @return a {@link AndNode} with the current object as the first operator and the given node as the second operator
     */
    public AndNode and(AbstractOperatorNode node)
    {
        return new AndNode(this, node);
    }

    /**
     * Helper to construct new {@link OrNode} using the current object.
     *
     * @param node the node that should be the second operand of the OR node
     * @return a {@link OrNode} with the current object as the first operator and the given node as the second operator
     */
    public OrNode or(AbstractOperatorNode node)
    {
        return new OrNode(this, node);
    }
}
