/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.refactoring.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.model.reference.DocumentReference;

/**
 * Provides configuration from the {@code Refactoring.Code.RefactoringConfigurationClass} document in the current wiki.
 * If the {@code Refactoring.Code.RefactoringConfigurationClass} xobject exists in the
 * {@code Refactoring.Code.RefactoringConfiguration} document then always use configuration values from it and if it
 * doesn't then use the passed default value.
 *
 * @version $Id: d4d0e535e222fff79c42304a82758ca790e579c4 $
 * @since 12.8RC1
 */
@Component
@Singleton
@Named("refactoring")
public class RefactoringConfigurationSource extends AbstractRefactoringConfigurationSource
{
    @Override
    protected DocumentReference getDocumentReference()
    {
        return new DocumentReference(DOCUMENT_REFERENCE, this.getCurrentWikiReference());
    }

    @Override
    protected String getCacheId()
    {
        return "configuration.document.refactoring";
    }
}
