/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.search.solr.internal;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;

import com.xpn.xwiki.doc.AbstractMandatoryClassInitializer;
import com.xpn.xwiki.objects.classes.BaseClass;

/**
 * Initializes the configuration class for the indexing user.
 *
 * @version $Id: ca227d9a89f34509f40d8690937fb8599a7a6ad0 $
 * @since 14.8M1
 */
@Component
@Named("XWiki.SolrSearchAdminIndexingUserClass")
@Singleton
public class IndexingUserClassInitializer extends AbstractMandatoryClassInitializer
{
    /**
     * Constructor setting the class page reference.
     */
    public IndexingUserClassInitializer()
    {
        super(DefaultIndexingUserConfig.CONFIG_CLASS);
    }

    /**
     * Class is only needed in the main wiki.
     * @return always true
     */
    @Override
    public boolean isMainWikiOnly()
    {
        return true;
    }

    @Override
    protected void createClass(BaseClass xclass)
    {
        xclass.addUsersField(DefaultIndexingUserConfig.CONFIG_USER_ATTRIBUTE, "Indexing User", 5, false);
    }
}
