/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.skin;

import java.time.Instant;

import org.xwiki.filter.input.InputSource;
import org.xwiki.stability.Unstable;

/**
 * @param <I> the type of the {@link InputSource}
 * @version $Id: d2a94674a99041a4a70fc7366898fe02ed4f5712 $
 * @since 7.0M1
 */
public interface Resource<I extends InputSource>
{
    /**
     * @return the repository containing the resource
     */
    ResourceRepository getRepository();

    /**
     * @return the unique identifier of the resource
     */
    String getId();

    /**
     * @return the path of the resource
     */
    String getPath();

    /**
     * @return the name of the resource (usually a relative path)
     * @since 8.3RC1
     */
    String getResourceName();

    /**
     * Provide an {@link InputSource} to read the resource.
     * 
     * @return an {@link InputSource} to read the resource
     * @throws Exception when failing to create a {@link InputSource} for the resource
     */
    I getInputSource() throws Exception;

    /**
     * @return the instant that resource was last modified or null if it's unknown
     * @throws Exception when failing to get the instant of the resource
     * @since 15.8RC1
     */
    @Unstable
    default Instant getInstant() throws Exception
    {
        return null;
    }

    /**
     * Create a URL for the resource.
     * 
     * @param forceSkinAction true if a dynamic skin URL should be forced
     * @return a URL to the resource
     * @throws Exception when failing to create a URL for the resource
     */
    String getURL(boolean forceSkinAction) throws Exception;
}
