/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.store;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;

import org.apache.commons.io.IOUtils;

/**
 * Serialize a {@link StreamProvider} to a File.
 * 
 * @version $Id: 4850962cbae5ba9603d8c52f87aa9200ba547597 $
 * @since 9.0RC1
 */
public class StreamProviderFileSerializer implements FileSerializer
{
    private final StreamProvider provider;

    /**
     * @param provider the provider to read
     */
    public StreamProviderFileSerializer(StreamProvider provider)
    {
        this.provider = provider;
    }

    @Override
    public void serialize(File file) throws Exception
    {
        try (InputStream in = this.provider.getStream()) {
            try (OutputStream out = new FileOutputStream(file)) {
                IOUtils.copy(in, out);
            }
        }
    }
}
