/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.vfs.internal.script;

import java.net.URI;

import org.junit.jupiter.api.Test;
import org.xwiki.test.junit5.mockito.ComponentTest;
import org.xwiki.test.junit5.mockito.InjectMockComponents;
import org.xwiki.test.junit5.mockito.MockComponent;
import org.xwiki.vfs.VfsException;
import org.xwiki.vfs.VfsManager;
import org.xwiki.vfs.VfsResourceReference;
import org.xwiki.vfs.script.VfsScriptService;

import static org.mockito.Mockito.verify;

/**
 * Validate {@link VfsScriptService}.
 * 
 * @version $Id: 7cc7e3d44cca0c1b6a3b35b8f145785628ff33f4 $
 */
@ComponentTest
public class VfsScriptServiceTest
{
    @MockComponent
    VfsManager vfsManager;

    @InjectMockComponents
    VfsScriptService scriptService;

    @Test
    void urlWithContentType() throws VfsException
    {
        VfsResourceReference reference =
            new VfsResourceReference(URI.create("attach:Sandbox.WebHome@my.zip/path/to/file"));

        this.scriptService.url(reference, "custom content type");

        VfsResourceReference sentReference =
            new VfsResourceReference(URI.create("attach:Sandbox.WebHome@my.zip/path/to/file"));
        sentReference.setContentType("custom content type");

        verify(this.vfsManager).getURL(sentReference);
    }
}
